[nautilus-actions] NAImportMode is renamed to FMAImportMode



commit a7b802508543d590c08bfe1de1c630843fe45475
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Sep 8 00:02:50 2015 +0200

    NAImportMode is renamed to FMAImportMode

 src/core/Makefile.am                             |    4 +-
 src/core/{na-import-mode.c => fma-import-mode.c} |  150 +++++++++++-----------
 src/core/fma-import-mode.h                       |   85 ++++++++++++
 src/core/fma-importer-ask.c                      |    4 +-
 src/core/fma-importer.c                          |   28 ++--
 src/core/na-import-mode.h                        |   85 ------------
 src/nact/nact-assistant-import.c                 |    6 +-
 src/nact/nact-preferences-editor.c               |    4 +-
 8 files changed, 183 insertions(+), 183 deletions(-)
---
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index 546eaab..18fcfac 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -84,8 +84,8 @@ libna_core_la_SOURCES = \
        fma-ifactory-provider.c                                                         \
        fma-iimporter.c                                                                         \
        fma-iio-provider.c                                                                      \
-       na-import-mode.c                                                                        \
-       na-import-mode.h                                                                        \
+       fma-import-mode.c                                                                       \
+       fma-import-mode.h                                                                       \
        fma-importer.c                                                                          \
        fma-importer.h                                                                          \
        fma-importer-ask.c                                                                      \
diff --git a/src/core/na-import-mode.c b/src/core/fma-import-mode.c
similarity index 73%
rename from src/core/na-import-mode.c
rename to src/core/fma-import-mode.c
index c70bfc8..6f11fe9 100644
--- a/src/core/na-import-mode.c
+++ b/src/core/fma-import-mode.c
@@ -33,18 +33,18 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-#include "na-import-mode.h"
+#include "fma-import-mode.h"
 #include "na-ioption.h"
 
 /* private class data
  */
-struct _NAImportModeClassPrivate {
+struct _FMAImportModeClassPrivate {
        void *empty;                                            /* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct _NAImportModePrivate {
+struct _FMAImportModePrivate {
        gboolean   dispose_has_run;
 
        /* properties
@@ -61,18 +61,18 @@ struct _NAImportModePrivate {
 enum {
        MAIN_PROP_0 = 0,
 
-       NA_IMPORT_PROP_MODE_ID,
-       NA_IMPORT_PROP_LABEL_ID,
-       NA_IMPORT_PROP_DESCRIPTION_ID,
-       NA_IMPORT_PROP_IMAGE_ID,
+       FMA_IMPORT_PROP_MODE_ID,
+       FMA_IMPORT_PROP_LABEL_ID,
+       FMA_IMPORT_PROP_DESCRIPTION_ID,
+       FMA_IMPORT_PROP_IMAGE_ID,
 
-       NA_IMPORT_PROP_N_PROPERTIES
+       FMA_IMPORT_PROP_N_PROPERTIES
 };
 
 static GObjectClass *st_parent_class = NULL;
 
 static GType      register_type( void );
-static void       class_init( NAImportModeClass *klass );
+static void       class_init( FMAImportModeClass *klass );
 static void       ioption_iface_init( NAIOptionInterface *iface, void *user_data );
 static gchar     *ioption_get_id( const NAIOption *option );
 static gchar     *ioption_get_label( const NAIOption *option );
@@ -85,7 +85,7 @@ static void       instance_dispose( GObject *object );
 static void       instance_finalize( GObject *object );
 
 GType
-na_import_mode_get_type( void )
+fma_import_mode_get_type( void )
 {
        static GType object_type = 0;
 
@@ -99,17 +99,17 @@ na_import_mode_get_type( void )
 static GType
 register_type( void )
 {
-       static const gchar *thisfn = "na_import_mode_register_type";
+       static const gchar *thisfn = "fma_import_mode_register_type";
        GType type;
 
        static GTypeInfo info = {
-               sizeof( NAImportModeClass ),
+               sizeof( FMAImportModeClass ),
                ( GBaseInitFunc ) NULL,
                ( GBaseFinalizeFunc ) NULL,
                ( GClassInitFunc ) class_init,
                NULL,
                NULL,
-               sizeof( NAImportMode ),
+               sizeof( FMAImportMode ),
                0,
                ( GInstanceInitFunc ) instance_init
        };
@@ -122,7 +122,7 @@ register_type( void )
                NULL
        };
 
-       type = g_type_register_static( G_TYPE_OBJECT, "NAImportMode", &info, 0 );
+       type = g_type_register_static( G_TYPE_OBJECT, "FMAImportMode", &info, 0 );
 
        g_type_add_interface_static( type, NA_TYPE_IOPTION, &ioption_iface_info );
 
@@ -130,9 +130,9 @@ register_type( void )
 }
 
 static void
-class_init( NAImportModeClass *klass )
+class_init( FMAImportModeClass *klass )
 {
-       static const gchar *thisfn = "na_import_mode_class_init";
+       static const gchar *thisfn = "fma_import_mode_class_init";
        GObjectClass *object_class;
 
        g_debug( "%s: klass=%p", thisfn, ( void * ) klass );
@@ -145,35 +145,35 @@ class_init( NAImportModeClass *klass )
        object_class->dispose = instance_dispose;
        object_class->finalize = instance_finalize;
 
-       klass->private = g_new0( NAImportModeClassPrivate, 1 );
+       klass->private = g_new0( FMAImportModeClassPrivate, 1 );
 
-       g_object_class_install_property( object_class, NA_IMPORT_PROP_MODE_ID,
+       g_object_class_install_property( object_class, FMA_IMPORT_PROP_MODE_ID,
                        g_param_spec_string(
-                                       NA_IMPORT_PROP_MODE,
+                                       FMA_IMPORT_PROP_MODE,
                                        "Import mode",
                                        "The string identifier of the import mode, stored in user's 
preferences",
                                        "",
                                        G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 
-       g_object_class_install_property( object_class, NA_IMPORT_PROP_LABEL_ID,
+       g_object_class_install_property( object_class, FMA_IMPORT_PROP_LABEL_ID,
                        g_param_spec_string(
-                                       NA_IMPORT_PROP_LABEL,
+                                       FMA_IMPORT_PROP_LABEL,
                                        "Import label",
                                        "The label associated to the import mode",
                                        "",
                                        G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 
-       g_object_class_install_property( object_class, NA_IMPORT_PROP_DESCRIPTION_ID,
+       g_object_class_install_property( object_class, FMA_IMPORT_PROP_DESCRIPTION_ID,
                        g_param_spec_string(
-                                       NA_IMPORT_PROP_DESCRIPTION,
+                                       FMA_IMPORT_PROP_DESCRIPTION,
                                        "Import mode description",
                                        "The description associated to the import mode",
                                        "",
                                        G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
 
-       g_object_class_install_property( object_class, NA_IMPORT_PROP_IMAGE_ID,
+       g_object_class_install_property( object_class, FMA_IMPORT_PROP_IMAGE_ID,
                        g_param_spec_pointer(
-                                       NA_IMPORT_PROP_IMAGE,
+                                       FMA_IMPORT_PROP_IMAGE,
                                        "Import mode image",
                                        "The image associated to the import mode, as a GdkPixbuf",
                                        G_PARAM_CONSTRUCT | G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE ));
@@ -182,7 +182,7 @@ class_init( NAImportModeClass *klass )
 static void
 ioption_iface_init( NAIOptionInterface *iface, void *user_data )
 {
-       static const gchar *thisfn = "na_import_mode_ioption_iface_init";
+       static const gchar *thisfn = "fma_import_mode_ioption_iface_init";
 
        g_debug( "%s: iface=%p, user_data=%p", thisfn, ( void * ) iface, ( void * ) user_data );
 
@@ -203,10 +203,10 @@ static gchar *
 ioption_get_id( const NAIOption *option )
 {
        gchar *id;
-       NAImportMode *mode;
+       FMAImportMode *mode;
 
-       g_return_val_if_fail( NA_IS_IMPORT_MODE( option ), NULL );
-       mode = NA_IMPORT_MODE( option );
+       g_return_val_if_fail( FMA_IS_IMPORT_MODE( option ), NULL );
+       mode = FMA_IMPORT_MODE( option );
        id = NULL;
 
        if( !mode->private->dispose_has_run ){
@@ -228,10 +228,10 @@ static gchar *
 ioption_get_label( const NAIOption *option )
 {
        gchar *label;
-       NAImportMode *mode;
+       FMAImportMode *mode;
 
-       g_return_val_if_fail( NA_IS_IMPORT_MODE( option ), NULL );
-       mode = NA_IMPORT_MODE( option );
+       g_return_val_if_fail( FMA_IS_IMPORT_MODE( option ), NULL );
+       mode = FMA_IMPORT_MODE( option );
        label = NULL;
 
        if( !mode->private->dispose_has_run ){
@@ -253,10 +253,10 @@ static gchar *
 ioption_get_description( const NAIOption *option )
 {
        gchar *description;
-       NAImportMode *mode;
+       FMAImportMode *mode;
 
-       g_return_val_if_fail( NA_IS_IMPORT_MODE( option ), NULL );
-       mode = NA_IMPORT_MODE( option );
+       g_return_val_if_fail( FMA_IS_IMPORT_MODE( option ), NULL );
+       mode = FMA_IMPORT_MODE( option );
        description = NULL;
 
        if( !mode->private->dispose_has_run ){
@@ -278,10 +278,10 @@ static GdkPixbuf *
 ioption_get_pixbuf( const NAIOption *option )
 {
        GdkPixbuf *pixbuf;
-       NAImportMode *mode;
+       FMAImportMode *mode;
 
-       g_return_val_if_fail( NA_IS_IMPORT_MODE( option ), NULL );
-       mode = NA_IMPORT_MODE( option );
+       g_return_val_if_fail( FMA_IS_IMPORT_MODE( option ), NULL );
+       mode = FMA_IMPORT_MODE( option );
        pixbuf = NULL;
 
        if( !mode->private->dispose_has_run ){
@@ -295,16 +295,16 @@ ioption_get_pixbuf( const NAIOption *option )
 static void
 instance_init( GTypeInstance *instance, gpointer klass )
 {
-       static const gchar *thisfn = "na_import_mode_instance_init";
-       NAImportMode *self;
+       static const gchar *thisfn = "fma_import_mode_instance_init";
+       FMAImportMode *self;
 
-       g_return_if_fail( NA_IS_IMPORT_MODE( instance ));
+       g_return_if_fail( FMA_IS_IMPORT_MODE( instance ));
 
        g_debug( "%s: instance=%p (%s), klass=%p",
                        thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-       self = NA_IMPORT_MODE( instance );
+       self = FMA_IMPORT_MODE( instance );
 
-       self->private = g_new0( NAImportModePrivate, 1 );
+       self->private = g_new0( FMAImportModePrivate, 1 );
 
        self->private->dispose_has_run = FALSE;
 }
@@ -312,27 +312,27 @@ instance_init( GTypeInstance *instance, gpointer klass )
 static void
 instance_get_property( GObject *object, guint property_id, GValue *value, GParamSpec *spec )
 {
-       NAImportMode *self;
+       FMAImportMode *self;
 
-       g_return_if_fail( NA_IS_IMPORT_MODE( object ));
-       self = NA_IMPORT_MODE( object );
+       g_return_if_fail( FMA_IS_IMPORT_MODE( object ));
+       self = FMA_IMPORT_MODE( object );
 
        if( !self->private->dispose_has_run ){
 
                switch( property_id ){
-                       case NA_IMPORT_PROP_MODE_ID:
+                       case FMA_IMPORT_PROP_MODE_ID:
                                g_value_set_string( value, self->private->mode );
                                break;
 
-                       case NA_IMPORT_PROP_LABEL_ID:
+                       case FMA_IMPORT_PROP_LABEL_ID:
                                g_value_set_string( value, self->private->label );
                                break;
 
-                       case NA_IMPORT_PROP_DESCRIPTION_ID:
+                       case FMA_IMPORT_PROP_DESCRIPTION_ID:
                                g_value_set_string( value, self->private->description );
                                break;
 
-                       case NA_IMPORT_PROP_IMAGE_ID:
+                       case FMA_IMPORT_PROP_IMAGE_ID:
                                g_value_set_pointer( value, self->private->image );
                                break;
 
@@ -346,30 +346,30 @@ instance_get_property( GObject *object, guint property_id, GValue *value, GParam
 static void
 instance_set_property( GObject *object, guint property_id, const GValue *value, GParamSpec *spec )
 {
-       NAImportMode *self;
+       FMAImportMode *self;
 
-       g_return_if_fail( NA_IS_IMPORT_MODE( object ));
-       self = NA_IMPORT_MODE( object );
+       g_return_if_fail( FMA_IS_IMPORT_MODE( object ));
+       self = FMA_IMPORT_MODE( object );
 
        if( !self->private->dispose_has_run ){
 
                switch( property_id ){
-                       case NA_IMPORT_PROP_MODE_ID:
+                       case FMA_IMPORT_PROP_MODE_ID:
                                g_free( self->private->mode );
                                self->private->mode = g_value_dup_string( value );
                                break;
 
-                       case NA_IMPORT_PROP_LABEL_ID:
+                       case FMA_IMPORT_PROP_LABEL_ID:
                                g_free( self->private->label );
                                self->private->label = g_value_dup_string( value );
                                break;
 
-                       case NA_IMPORT_PROP_DESCRIPTION_ID:
+                       case FMA_IMPORT_PROP_DESCRIPTION_ID:
                                g_free( self->private->description );
                                self->private->description = g_value_dup_string( value );
                                break;
 
-                       case NA_IMPORT_PROP_IMAGE_ID:
+                       case FMA_IMPORT_PROP_IMAGE_ID:
                                self->private->image = g_value_get_pointer( value );
                                break;
 
@@ -383,12 +383,12 @@ instance_set_property( GObject *object, guint property_id, const GValue *value,
 static void
 instance_dispose( GObject *object )
 {
-       static const gchar *thisfn = "na_import_mode_instance_dispose";
-       NAImportMode *self;
+       static const gchar *thisfn = "fma_import_mode_instance_dispose";
+       FMAImportMode *self;
 
-       g_return_if_fail( NA_IS_IMPORT_MODE( object ));
+       g_return_if_fail( FMA_IS_IMPORT_MODE( object ));
 
-       self = NA_IMPORT_MODE( object );
+       self = FMA_IMPORT_MODE( object );
 
        if( !self->private->dispose_has_run ){
 
@@ -406,14 +406,14 @@ instance_dispose( GObject *object )
 static void
 instance_finalize( GObject *object )
 {
-       static const gchar *thisfn = "na_import_mode_instance_finalize";
-       NAImportMode *self;
+       static const gchar *thisfn = "fma_import_mode_instance_finalize";
+       FMAImportMode *self;
 
-       g_return_if_fail( NA_IS_IMPORT_MODE( object ));
+       g_return_if_fail( FMA_IS_IMPORT_MODE( object ));
 
        g_debug( "%s: object=%p", thisfn, ( void * ) object );
 
-       self = NA_IMPORT_MODE( object );
+       self = FMA_IMPORT_MODE( object );
 
        g_free( self->private );
 
@@ -424,19 +424,19 @@ instance_finalize( GObject *object )
 }
 
 /*
- * na_import_mode_new:
+ * fma_import_mode_new:
  * @mode_id: the internal identifier of the import mode.
  *
- * Returns: a newly allocated #NAImportMode object.
+ * Returns: a newly allocated #FMAImportMode object.
  *
  * Since: 3.2
  */
-NAImportMode *
-na_import_mode_new( guint mode_id )
+FMAImportMode *
+fma_import_mode_new( guint mode_id )
 {
-       NAImportMode *mode;
+       FMAImportMode *mode;
 
-       mode = g_object_new( NA_TYPE_IMPORT_MODE, NULL );
+       mode = g_object_new( FMA_TYPE_IMPORT_MODE, NULL );
 
        mode->private->id = mode_id;
 
@@ -444,19 +444,19 @@ na_import_mode_new( guint mode_id )
 }
 
 /*
- * na_import_mode_get_id:
- * @mode: a #NAImportMode object.
+ * fma_import_mode_get_id:
+ * @mode: a #FMAImportMode object.
  *
  * Returns: the internal identifier of the import mode.
  *
  * Since: 3.2
  */
 guint
-na_import_mode_get_id( const NAImportMode *mode )
+fma_import_mode_get_id( const FMAImportMode *mode )
 {
        guint id;
 
-       g_return_val_if_fail( NA_IS_IMPORT_MODE( mode ), 0 );
+       g_return_val_if_fail( FMA_IS_IMPORT_MODE( mode ), 0 );
 
        id = 0;
 
diff --git a/src/core/fma-import-mode.h b/src/core/fma-import-mode.h
new file mode 100644
index 0000000..d7f7e3f
--- /dev/null
+++ b/src/core/fma-import-mode.h
@@ -0,0 +1,85 @@
+/*
+ * FileManager-Actions
+ * A file-manager extension which offers configurable context menu actions.
+ *
+ * Copyright (C) 2005 The GNOME Foundation
+ * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
+ * Copyright (C) 2009-2015 Pierre Wieser and others (see AUTHORS)
+ *
+ * FileManager-Actions is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of
+ * the License, or (at your option) any later version.
+ *
+ * FileManager-Actions is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with FileManager-Actions; see the file COPYING. If not, see
+ * <http://www.gnu.org/licenses/>.
+ *
+ * Authors:
+ *   Frederic Ruaudel <grumz grumz net>
+ *   Rodrigo Moya <rodrigo gnome-db org>
+ *   Pierre Wieser <pwieser trychlos org>
+ *   ... and many others (see AUTHORS)
+ */
+
+#ifndef __CORE_FMA_IMPORT_MODE_H__
+#define __CORE_FMA_IMPORT_MODE_H__
+
+/* @title: FMAImportMode
+ * @short_description: The #FMAImportMode Class Definition
+ * @include: core/fma-import-mode.h
+ *
+ * This class gathers and manages the different import modes we are able
+ * to deal with.
+ */
+
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <glib.h>
+
+G_BEGIN_DECLS
+
+#define FMA_TYPE_IMPORT_MODE                ( fma_import_mode_get_type())
+#define FMA_IMPORT_MODE( object )           ( G_TYPE_CHECK_INSTANCE_CAST( object, FMA_TYPE_IMPORT_MODE, 
FMAImportMode ))
+#define FMA_IMPORT_MODE_CLASS( klass )      ( G_TYPE_CHECK_CLASS_CAST( klass, FMA_TYPE_IMPORT_MODE, 
FMAImportModeClass ))
+#define FMA_IS_IMPORT_MODE( object )        ( G_TYPE_CHECK_INSTANCE_TYPE( object, FMA_TYPE_IMPORT_MODE ))
+#define FMA_IS_IMPORT_MODE_CLASS( klass )   ( G_TYPE_CHECK_CLASS_TYPE(( klass ), FMA_TYPE_IMPORT_MODE ))
+#define FMA_IMPORT_MODE_GET_CLASS( object ) ( G_TYPE_INSTANCE_GET_CLASS(( object ), FMA_TYPE_IMPORT_MODE, 
FMAImportModeClass ))
+
+typedef struct _FMAImportModePrivate        FMAImportModePrivate;
+
+typedef struct {
+       GObject               parent;
+       FMAImportModePrivate *private;
+}
+       FMAImportMode;
+
+typedef struct _FMAImportModeClassPrivate   FMAImportModeClassPrivate;
+
+typedef struct {
+       GObjectClass               parent;
+       FMAImportModeClassPrivate *private;
+}
+       FMAImportModeClass;
+
+GType          fma_import_mode_get_type( void );
+
+/* FMAImportMode properties
+ *
+ */
+#define FMA_IMPORT_PROP_MODE                   "fma-import-mode-prop-mode"
+#define FMA_IMPORT_PROP_LABEL                  "fma-import-mode-prop-label"
+#define FMA_IMPORT_PROP_DESCRIPTION            "fma-import-mode-prop-description"
+#define FMA_IMPORT_PROP_IMAGE                  "fma-import-mode-prop-image"
+
+FMAImportMode *fma_import_mode_new     ( guint mode_id );
+
+guint          fma_import_mode_get_id  ( const FMAImportMode *mode );
+
+G_END_DECLS
+
+#endif /* __CORE_FMA_IMPORT_MODE_H__ */
diff --git a/src/core/fma-importer-ask.c b/src/core/fma-importer-ask.c
index a69e1a2..d1f13f2 100644
--- a/src/core/fma-importer-ask.c
+++ b/src/core/fma-importer-ask.c
@@ -37,7 +37,7 @@
 #include <api/fma-object-api.h>
 
 #include "fma-gtk-utils.h"
-#include "na-import-mode.h"
+#include "fma-import-mode.h"
 #include "fma-importer.h"
 #include "fma-importer-ask.h"
 #include "na-ioptions-list.h"
@@ -440,7 +440,7 @@ get_selected_mode( FMAImporterAsk *editor )
        na_settings_set_string( NA_IPREFS_IMPORT_ASK_USER_LAST_MODE, mode_id );
        g_free( mode_id );
 
-       editor->private->mode = na_import_mode_get_id( NA_IMPORT_MODE( mode ));
+       editor->private->mode = fma_import_mode_get_id( FMA_IMPORT_MODE( mode ));
 
        button = fma_gtk_utils_find_widget_by_name( GTK_CONTAINER( editor->private->toplevel ), 
"AskKeepChoiceButton" );
        keep = gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( button ));
diff --git a/src/nact/nact-assistant-import.c b/src/nact/nact-assistant-import.c
index 9ef626b..f33e5da 100644
--- a/src/nact/nact-assistant-import.c
+++ b/src/nact/nact-assistant-import.c
@@ -38,7 +38,7 @@
 #include <api/fma-object-api.h>
 #include <api/fma-core-utils.h>
 
-#include <core/na-import-mode.h>
+#include <core/fma-import-mode.h>
 #include <core/fma-importer.h>
 #include <core/na-ioptions-list.h>
 #include <core/fma-gtk-utils.h>
@@ -621,7 +621,7 @@ prepare_confirm( NactAssistantImport *window, GtkAssistant *assistant, GtkWidget
        g_return_if_fail( GTK_IS_LABEL( label ));
        window->private->mode = na_ioptions_list_get_selected(
                        NA_IOPTIONS_LIST( window ), GTK_WIDGET( window->private->duplicates_listview ));
-       g_return_if_fail( NA_IS_IMPORT_MODE( window->private->mode ));
+       g_return_if_fail( FMA_IS_IMPORT_MODE( window->private->mode ));
        mode_label = na_ioption_get_label( window->private->mode );
        label2 = fma_core_utils_str_remove_char( mode_label, "_" );
        mode_description = na_ioption_get_description( window->private->mode );
@@ -664,7 +664,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
        importer_parms.uris = gtk_file_chooser_get_uris( GTK_FILE_CHOOSER( window->private->file_chooser ));
        importer_parms.check_fn = ( FMAImporterCheckFn ) check_for_existence;
        importer_parms.check_fn_data = main_window;
-       importer_parms.preferred_mode = na_import_mode_get_id( NA_IMPORT_MODE( window->private->mode ));
+       importer_parms.preferred_mode = fma_import_mode_get_id( FMA_IMPORT_MODE( window->private->mode ));
        importer_parms.parent_toplevel = base_window_get_gtk_toplevel( BASE_WINDOW( wnd ));
 
        import_results = fma_importer_import_from_uris( NA_PIVOT( updater ), &importer_parms );
diff --git a/src/nact/nact-preferences-editor.c b/src/nact/nact-preferences-editor.c
index d50dd13..3558fa8 100644
--- a/src/nact/nact-preferences-editor.c
+++ b/src/nact/nact-preferences-editor.c
@@ -40,7 +40,7 @@
 #include <core/fma-exporter.h>
 #include <core/fma-export-format.h>
 #include <core/fma-gtk-utils.h>
-#include <core/na-import-mode.h>
+#include <core/fma-import-mode.h>
 #include <core/fma-importer.h>
 #include <core/na-ioptions-list.h>
 #include <core/na-iprefs.h>
@@ -1245,7 +1245,7 @@ on_dialog_ok( BaseDialog *dialog )
                if( !editor->private->import_mode_mandatory ){
                        container = base_window_get_widget( BASE_WINDOW( editor ), 
"PreferencesImportModeVBox" );
                        option = na_ioptions_list_get_selected( NA_IOPTIONS_LIST( editor ), container );
-                       g_return_if_fail( NA_IS_IMPORT_MODE( option ));
+                       g_return_if_fail( FMA_IS_IMPORT_MODE( option ));
                        import_mode = na_ioption_get_id( option );
                        na_settings_set_string( NA_IPREFS_IMPORT_PREFERRED_MODE, import_mode );
                        g_free( import_mode );


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/core/fma-importer.c b/src/core/fma-importer.c
index 59a9386..1b94f85 100644
--- a/src/core/fma-importer.c
+++ b/src/core/fma-importer.c
@@ -38,7 +38,7 @@
 #include <api/fma-iimporter.h>
 #include <api/fma-object-api.h>
 
-#include "na-import-mode.h"
+#include "fma-import-mode.h"
 #include "fma-importer.h"
 #include "fma-importer-ask.h"
 
@@ -49,9 +49,9 @@ typedef struct {
        const gchar *description;               /* full description */
        gchar       *image;                             /* associated image */
 }
-       NAImportModeStr;
+       FMAImportModeStr;
 
-static NAImportModeStr st_import_modes[] = {
+static FMAImportModeStr st_import_modes[] = {
 
        { IMPORTER_MODE_NO_IMPORT,
                        "NoImport",
@@ -80,7 +80,7 @@ static NAImportModeStr st_import_modes[] = {
        { 0 }
 };
 
-static NAImportModeStr st_import_ask_mode = {
+static FMAImportModeStr st_import_ask_mode = {
 
        IMPORTER_MODE_ASK,
                        "Ask",
@@ -95,7 +95,7 @@ static FMAObjectItem     *is_importing_already_exists( FMAImporterParms *parms,
 static void              renumber_label_item( FMAObjectItem *item );
 static guint             ask_user_for_mode( const FMAObjectItem *importing, const FMAObjectItem *existing, 
FMAImporterAskUserParms *parms );
 static guint             get_id_from_string( const gchar *str );
-static NAIOption        *get_mode_from_struct( const NAImportModeStr *str );
+static NAIOption        *get_mode_from_struct( const FMAImportModeStr *str );
 
 /* i18n: '%s' stands for the file URI */
 #define ERR_NOT_LOADABLE       _( "%s is not loadable (empty or too big or not a regular file)" )
@@ -489,9 +489,9 @@ fma_importer_get_modes( void )
 }
 
 static NAIOption *
-get_mode_from_struct( const NAImportModeStr *str )
+get_mode_from_struct( const FMAImportModeStr *str )
 {
-       NAImportMode *mode;
+       FMAImportMode *mode;
        gint width, height;
        gchar *fname;
        GdkPixbuf *pixbuf;
@@ -500,7 +500,7 @@ get_mode_from_struct( const NAImportModeStr *str )
                width = height = 48;
        }
 
-       mode = na_import_mode_new( str->id );
+       mode = fma_import_mode_new( str->id );
        pixbuf = NULL;
 
        if( str->image && g_utf8_strlen( str->image, -1 )){
@@ -509,10 +509,10 @@ get_mode_from_struct( const NAImportModeStr *str )
                g_free( fname );
        }
        g_object_set( G_OBJECT( mode ),
-               NA_IMPORT_PROP_MODE,        str->mode,
-               NA_IMPORT_PROP_LABEL,       gettext( str->label ),
-               NA_IMPORT_PROP_DESCRIPTION, gettext( str->description ),
-               NA_IMPORT_PROP_IMAGE,       pixbuf,
+               FMA_IMPORT_PROP_MODE,        str->mode,
+               FMA_IMPORT_PROP_LABEL,       gettext( str->label ),
+               FMA_IMPORT_PROP_DESCRIPTION, gettext( str->description ),
+               FMA_IMPORT_PROP_IMAGE,       pixbuf,
                NULL );
 
        return( NA_IOPTION( mode ));
@@ -520,7 +520,7 @@ get_mode_from_struct( const NAImportModeStr *str )
 
 /*
  * fma_importer_free_modes:
  * @modes: a #GList of #NAImportMode items, as returned by fma_importer_get_modes().
  *
  * Releases the resources allocated to the @modes list.
  */
@@ -538,7 +538,7 @@ fma_importer_free_modes( GList *modes )
 /*
  * fma_importer_get_ask_mode:
  *
  * Returns: a #NAImportMode object which describes the 'Ask me' option.
  */
 NAIOption *
 fma_importer_get_ask_mode( void )
@@ -520,7 +520,7 @@ get_mode_from_struct( const NAImportModeStr *str )
 /*
  * fma_importer_free_modes:
- * @modes: a #GList of #NAImportMode items, as returned by fma_importer_get_modes().
+ * @modes: a #GList of #FMAImportMode items, as returned by fma_importer_get_modes().
  *
  * Releases the resources allocated to the @modes list.
@@ -538,7 +538,7 @@ fma_importer_free_modes( GList *modes )
  * fma_importer_get_ask_mode:
  *
- * Returns: a #NAImportMode object which describes the 'Ask me' option.
+ * Returns: a #FMAImportMode object which describes the 'Ask me' option.
  */
 NAIOption *